@@ -59,7 +59,10 @@ def container_start(container: str):
 
 
 def print_config():
-    [config_keys, get_config] = [Configurations().config_keys, Configurations().get_config]
+    [config_keys, get_config] = [
+        Configurations().config_keys,
+        Configurations().get_config,
+    ]
 
     grid = Table.grid(expand=True)
     grid.add_column("Key", style="cyan")
@@ -76,5 +79,5 @@ def print_config():
         title_align="left",
         border_style="dim",
     )
-    
-    print(panel)
\ No newline at end of file
+
+    print(panel)
